<?php
/**
 * Digital Marketing Expert: Customizer
 *
 * @subpackage Digital Marketing Expert
 * @since 1.0
 */

use WPTRT\Customize\Section\Digital_Marketing_Expert_Button;

add_action( 'customize_register', function( $manager ) {

	$manager->register_section_type( Digital_Marketing_Expert_Button::class );

	$manager->add_section(
		new Digital_Marketing_Expert_Button( $manager, 'digital_marketing_expert_pro', [
			'title' => __( 'Digital Marketing Pro', 'digital-marketing-expert' ),
			'priority' => 0,
			'button_text' => __( 'Go Pro', 'digital-marketing-expert' ),
			'button_url'  => esc_url( 'https://www.luzuk.com/product/wordpress-digital-marketing-theme/', 'digital-marketing-expert')
		] )
	);

} );

// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

	$version = wp_get_theme()->get( 'Version' );

	wp_enqueue_script(
		'digital-marketing-expert-customize-section-button',
		get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
		[ 'customize-controls' ],
		$version,
		true
	);

	wp_enqueue_style(
		'digital-marketing-expert-customize-section-button',
		get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
		[ 'customize-controls' ],
 		$version
	);

} );

function digital_marketing_expert_customize_register( $wp_customize ) {

	$wp_customize->add_setting('digital_marketing_expert_logo_padding',array(
		'sanitize_callback'	=> 'esc_html'
	));
	$wp_customize->add_control('digital_marketing_expert_logo_padding',array(
		'label' => __('Logo Margin','digital-marketing-expert'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting('digital_marketing_expert_logo_top_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'digital_marketing_expert_sanitize_float'
	));
	$wp_customize->add_control('digital_marketing_expert_logo_top_padding',array(
		'type' => 'number',
		'description' => __('Top','digital-marketing-expert'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('digital_marketing_expert_logo_bottom_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'digital_marketing_expert_sanitize_float'
	));
	$wp_customize->add_control('digital_marketing_expert_logo_bottom_padding',array(
		'type' => 'number',
		'description' => __('Bottom','digital-marketing-expert'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('digital_marketing_expert_logo_left_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'digital_marketing_expert_sanitize_float'
	));
	$wp_customize->add_control('digital_marketing_expert_logo_left_padding',array(
		'type' => 'number',
		'description' => __('Left','digital-marketing-expert'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('digital_marketing_expert_logo_right_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'digital_marketing_expert_sanitize_float'
 	));
 	$wp_customize->add_control('digital_marketing_expert_logo_right_padding',array(
		'type' => 'number',
		'description' => __('Right','digital-marketing-expert'),
		'section' => 'title_tagline',
    ));

	$wp_customize->add_setting('digital_marketing_expert_show_site_title',array(
		'default' => true,
		'sanitize_callback'	=> 'digital_marketing_expert_sanitize_checkbox'
	));
	$wp_customize->add_control('digital_marketing_expert_show_site_title',array(
		'type' => 'checkbox',
		'label' => __('Show / Hide Site Title','digital-marketing-expert'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting('digital_marketing_expert_show_tagline',array(
		'default' => true,
		'sanitize_callback'	=> 'digital_marketing_expert_sanitize_checkbox'
	));
	$wp_customize->add_control('digital_marketing_expert_show_tagline',array(
		'type' => 'checkbox',
		'label' => __('Show / Hide Site Tagline','digital-marketing-expert'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_panel( 'digital_marketing_expert_panel_id', array(
		'priority' => 10,
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => __( 'Theme Settings', 'digital-marketing-expert' ),
		'description' => __( 'Description of what this panel does.', 'digital-marketing-expert' ),
	) );

	$wp_customize->add_section( 'digital_marketing_expert_theme_options_section', array(
    	'title'      => __( 'General Settings', 'digital-marketing-expert' ),
		'priority'   => 30,
		'panel' => 'digital_marketing_expert_panel_id'
	) );

	$wp_customize->add_setting('digital_marketing_expert_theme_options',array(
		'default' => 'Right Sidebar',
		'sanitize_callback' => 'digital_marketing_expert_sanitize_choices'
	));
	$wp_customize->add_control('digital_marketing_expert_theme_options',array(
		'type' => 'select',
		'label' => __('Blog Page Sidebar Layout','digital-marketing-expert'),
		'section' => 'digital_marketing_expert_theme_options_section',
		'choices' => array(
		   'Left Sidebar' => __('Left Sidebar','digital-marketing-expert'),
		   'Right Sidebar' => __('Right Sidebar','digital-marketing-expert'),
		   'One Column' => __('One Column','digital-marketing-expert'),
		   'Grid Layout' => __('Grid Layout','digital-marketing-expert')
		),
	));

	$wp_customize->add_setting('digital_marketing_expert_single_post_sidebar',array(
		'default' => 'Right Sidebar',
		'sanitize_callback' => 'digital_marketing_expert_sanitize_choices'
	));
	$wp_customize->add_control('digital_marketing_expert_single_post_sidebar',array(
        'type' => 'select',
        'label' => __('Single Post Sidebar Layout','digital-marketing-expert'),
        'section' => 'digital_marketing_expert_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','digital-marketing-expert'),
            'Right Sidebar' => __('Right Sidebar','digital-marketing-expert'),
            'One Column' => __('One Column','digital-marketing-expert')
        ),
	));

	$wp_customize->add_setting('digital_marketing_expert_page_sidebar',array(
		'default' => 'One Column',
		'sanitize_callback' => 'digital_marketing_expert_sanitize_choices'
	));
	$wp_customize->add_control('digital_marketing_expert_page_sidebar',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','digital-marketing-expert'),
        'section' => 'digital_marketing_expert_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','digital-marketing-expert'),
            'Right Sidebar' => __('Right Sidebar','digital-marketing-expert'),
            'One Column' => __('One Column','digital-marketing-expert')
        ),
	));

	$wp_customize->add_setting('digital_marketing_expert_archive_page_sidebar',array(
		'default' => 'Right Sidebar',
		'sanitize_callback' => 'digital_marketing_expert_sanitize_choices'
	));
	$wp_customize->add_control('digital_marketing_expert_archive_page_sidebar',array(
        'type' => 'select',
        'label' => __('Archive & Search Page Sidebar Layout','digital-marketing-expert'),
        'section' => 'digital_marketing_expert_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','digital-marketing-expert'),
            'Right Sidebar' => __('Right Sidebar','digital-marketing-expert'),
            'One Column' => __('One Column','digital-marketing-expert'),
            'Grid Layout' => __('Grid Layout','digital-marketing-expert')
        ),
	));

	//Header
	$wp_customize->add_section( 'digital_marketing_expert_header_section' , array(
    	'title'    => __( 'Header', 'digital-marketing-expert' ),
		'priority' => null,
		'panel' => 'digital_marketing_expert_panel_id'
	) );

	$wp_customize->add_setting('digital_marketing_expert_phone_text',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('digital_marketing_expert_phone_text',array(
	   	'type' => 'text',
	   	'label' => __('Add Phone Text','digital-marketing-expert'),
	   	'section' => 'digital_marketing_expert_header_section',
	));

	$wp_customize->add_setting('digital_marketing_expert_phone_number',array(
    	'default' => '',
    	'sanitize_callback'	=> 'digital_marketing_expert_sanitize_phone_number'
	));
	$wp_customize->add_control('digital_marketing_expert_phone_number',array(
	   	'type' => 'text',
	   	'label' => __('Add Phone Number','digital-marketing-expert'),
	   	'section' => 'digital_marketing_expert_header_section',
	));

	$wp_customize->add_setting('digital_marketing_expert_contact_btn_text',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('digital_marketing_expert_contact_btn_text',array(
	   	'type' => 'text',
	   	'label' => __('Add Contact Button Text','digital-marketing-expert'),
	   	'section' => 'digital_marketing_expert_header_section',
	));

	$wp_customize->add_setting('digital_marketing_expert_contact_btn_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('digital_marketing_expert_contact_btn_url',array(
	   	'type' => 'text',
	   	'label' => __('Add Contact Button URL','digital-marketing-expert'),
	   	'section' => 'digital_marketing_expert_header_section',
	));

	$wp_customize->add_setting('digital_marketing_expert_facebook_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('digital_marketing_expert_facebook_url',array(
	   	'type' => 'url',
	   	'label' => __('Add Facebook URL','digital-marketing-expert'),
	   	'section' => 'digital_marketing_expert_header_section',
	));

	$wp_customize->add_setting('digital_marketing_expert_instagram_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('digital_marketing_expert_instagram_url',array(
	   	'type' => 'url',
	   	'label' => __('Add Instagram URL','digital-marketing-expert'),
	   	'section' => 'digital_marketing_expert_header_section',
	));

	$wp_customize->add_setting('digital_marketing_expert_twitter_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('digital_marketing_expert_twitter_url',array(
	   	'type' => 'url',
	   	'label' => __('Add Twitter URL','digital-marketing-expert'),
	   	'section' => 'digital_marketing_expert_header_section',
	));

	$wp_customize->add_setting('digital_marketing_expert_linkedin_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('digital_marketing_expert_linkedin_url',array(
	   	'type' => 'url',
	   	'label' => __('Add Linkedin URL','digital-marketing-expert'),
	   	'section' => 'digital_marketing_expert_header_section',
	));

	//home page slider
	$wp_customize->add_section( 'digital_marketing_expert_slider_section' , array(
    	'title'    => __( 'Slider Settings', 'digital-marketing-expert' ),
		'priority' => null,
		'panel' => 'digital_marketing_expert_panel_id'
	) );

	$wp_customize->add_setting('digital_marketing_expert_slider_hide_show',array(
    	'default' => false,
    	'sanitize_callback'	=> 'digital_marketing_expert_sanitize_checkbox'
	));
	$wp_customize->add_control('digital_marketing_expert_slider_hide_show',array(
	   	'type' => 'checkbox',
	   	'label' => __('Show / Hide Slider','digital-marketing-expert'),
	   	'section' => 'digital_marketing_expert_slider_section',
	));

	for ( $count = 1; $count <= 4; $count++ ) {
		$wp_customize->add_setting( 'digital_marketing_expert_slider' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'digital_marketing_expert_sanitize_dropdown_pages'
		));
		$wp_customize->add_control( 'digital_marketing_expert_slider' . $count, array(
			'label' => __('Select Slider Image Page', 'digital-marketing-expert' ),
			'description'=> __('Image size (500px x 500px)','digital-marketing-expert'),
			'section' => 'digital_marketing_expert_slider_section',
			'type' => 'dropdown-pages'
		));
	}

	//Services Section
	$wp_customize->add_section('digital_marketing_expert_service_section',array(
		'title'	=> __('Service Section','digital-marketing-expert'),
		'description'=> __('This section will appear below the slider.','digital-marketing-expert'),
		'panel' => 'digital_marketing_expert_panel_id',
	));

    $wp_customize->add_setting('digital_marketing_expert_section_title',array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('digital_marketing_expert_section_title',array(
		'label'	=> __('Section Title','digital-marketing-expert'),
		'section' => 'digital_marketing_expert_service_section',
		'type' => 'text'
	));

    $wp_customize->add_setting('digital_marketing_expert_section_text',array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('digital_marketing_expert_section_text',array(
		'label'	=> __('Section Text','digital-marketing-expert'),
		'section' => 'digital_marketing_expert_service_section',
		'type' => 'text'
	));

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_pst[]= 'select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_pst[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('digital_marketing_expert_category_setting',array(
		'default' => 'select',
		'sanitize_callback' => 'digital_marketing_expert_sanitize_choices',
	));
	$wp_customize->add_control('digital_marketing_expert_category_setting',array(
		'type' => 'select',
		'choices' => $cat_pst,
		'label' => __('Select Category to display Post','digital-marketing-expert'),
		'section' => 'digital_marketing_expert_service_section',
	));

	//Footer
    $wp_customize->add_section( 'digital_marketing_expert_footer', array(
    	'title'  => __( 'Footer Text', 'digital-marketing-expert' ),
		'priority' => null,
		'panel' => 'digital_marketing_expert_panel_id'
	) );

	$wp_customize->add_setting('digital_marketing_expert_show_back_totop',array(
       'default' => true,
       'sanitize_callback'	=> 'digital_marketing_expert_sanitize_checkbox'
    ));
    $wp_customize->add_control('digital_marketing_expert_show_back_totop',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide Back to Top','digital-marketing-expert'),
       'section' => 'digital_marketing_expert_footer'
    ));

    $wp_customize->add_setting('digital_marketing_expert_footer_copy',array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('digital_marketing_expert_footer_copy',array(
		'label'	=> __('Footer Text','digital-marketing-expert'),
		'section' => 'digital_marketing_expert_footer',
		'setting' => 'digital_marketing_expert_footer_copy',
		'type' => 'text'
	));

	$wp_customize->get_setting( 'blogname' )->transport          = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport   = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'digital_marketing_expert_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'digital_marketing_expert_customize_partial_blogdescription',
	) );
}
add_action( 'customize_register', 'digital_marketing_expert_customize_register' );

function digital_marketing_expert_customize_partial_blogname() {
	bloginfo( 'name' );
}

function digital_marketing_expert_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

function digital_marketing_expert_is_static_front_page() {
	return ( is_front_page() && ! is_home() );
}

function digital_marketing_expert_is_view_with_layout_option() {
	// This option is available on all pages. It's also available on archives when there isn't a sidebar.
	return ( is_page() || ( is_archive() && ! is_active_sidebar( 'sidebar-1' ) ) );
}